==> jc-1.4.0.tar.gz: scm/Mult.h <==
// class scm.Mult

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 782161544a6c6f81 scm_Mult
// @dep_class 6d0a82a28dffac88 scm_Procedure

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_Mult_H_
#define _JC_scm_Mult_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_Mult$sub_refs	_jc_scm_Mult$sub_refs;
typedef struct _jc_scm_Mult$sub_nonrefs	_jc_scm_Mult$sub_nonrefs;
typedef struct _jc_scm_Mult$refs	_jc_scm_Mult$refs;
typedef struct _jc_scm_Mult$nonrefs	_jc_scm_Mult$nonrefs;
typedef struct _jc_scm_Mult$object	_jc_scm_Mult$object;

typedef const struct _jc_scm_Mult$vmethods	_jc_scm_Mult$vmethods;
typedef const struct _jc_scm_Mult$vtable	_jc_scm_Mult$vtable;
typedef const struct _jc_scm_Mult$vtype	_jc_scm_Mult$vtype;

// Constructors
extern void _jc_scm_Mult$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_Mult$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_Mult$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_Mult$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_Mult$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_Mult$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_Mult$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_Mult$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_Mult$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_Mult$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_Mult$object *);
};

// Vtable
struct _jc_scm_Mult$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_Mult$vmethods	scm_Mult;
};

// Vtype
struct _jc_scm_Mult$vtype {
	_jc_type			type;
	_jc_scm_Mult$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Mult$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_Mult$refs {
    _jc_scm_Mult$sub_refs	scm_Mult;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Mult$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_Mult$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_Mult$sub_nonrefs	scm_Mult;
};

// Object instance structure
struct _jc_scm_Mult$object {
	_jc_scm_Mult$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Mult$vtype	*vtype;
	_jc_scm_Mult$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Mult$vtype _jc_scm_Mult$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Mult, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Mult$class_object;

#endif	/* _JC_scm_Mult_H_ */

==> jc-1.4.6.tar.gz: scm/Mult.h <==
// class scm.Mult

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 782161544a6c6f81 scm_Mult
// @dep_class 6d0a82a28dffac88 scm_Procedure

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_Mult_H_
#define _JC_scm_Mult_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_Mult$sub_refs	_jc_scm_Mult$sub_refs;
typedef struct _jc_scm_Mult$sub_nonrefs	_jc_scm_Mult$sub_nonrefs;
typedef struct _jc_scm_Mult$refs	_jc_scm_Mult$refs;
typedef struct _jc_scm_Mult$nonrefs	_jc_scm_Mult$nonrefs;
typedef struct _jc_scm_Mult$object	_jc_scm_Mult$object;

typedef const struct _jc_scm_Mult$vmethods	_jc_scm_Mult$vmethods;
typedef const struct _jc_scm_Mult$vtable	_jc_scm_Mult$vtable;
typedef const struct _jc_scm_Mult$vtype	_jc_scm_Mult$vtype;

// Constructors
extern void _jc_scm_Mult$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_Mult$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_Mult$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_Mult$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_Mult$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_Mult$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_Mult$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_Mult$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_Mult$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_Mult$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_Mult$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_Mult$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_Mult$vmethods	scm_Mult;
};

// Vtype
struct _jc_scm_Mult$vtype {
	_jc_type			type;
	_jc_scm_Mult$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Mult$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_Mult$refs {
    _jc_scm_Mult$sub_refs	scm_Mult;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Mult$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_Mult$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_Mult$sub_nonrefs	scm_Mult;
};

// Object instance structure
struct _jc_scm_Mult$object {
	_jc_scm_Mult$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Mult$vtype	*vtype;
	_jc_scm_Mult$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Mult$vtype _jc_scm_Mult$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Mult, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Mult$class_object;

#endif	/* _JC_scm_Mult_H_ */
